## Cookiecutter Hamster

[Cookiecutter](https://github.com/cookiecutter/cookiecutter) template for self hosted blogs

### Quickstart
* Install cookiecutter
``` bash
(venv) pip install cookiecutter
```

* Generate your shiny new project
``` bash
(venv) cookiecutter https://github.com/kulgan/cookiecutter-hamster.git
```

* After answering the questions, cd into project and initialize git
